<TS version="2.1" language="be">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Правы клік, каб рэдагаваць адрас ці метку</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Стварыць новы адрас</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">Новы</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">Капіяваць</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">Зачыніць</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Выдаліць абраны адрас са спісу</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Увядзіце адрас ці пазнаку для пошуку</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Экспартаваць гэтыя звесткі у файл</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Экспарт</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">Выдаліць</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Выбраць адрас, куды выслаць сродкі</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Выбраць адрас, на які атрымаць сродкі</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">Выбраць</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Тут знаходзяцца Біткойн-адрасы для высылання плацяжоў. Заўсёды спраўджвайце колькасць і адрас прызначэння перад здзяйсненнем транзакцыі.</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">Капіяваць адрас</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Капіяваць Метку</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">Рэдагаваць</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Экспартаваць Спіс Адрасоў</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Адбылася памылка падчас спробы захаваць адрас у %1. Паспрабуйце зноў.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Адрасы адпраўкі - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Адрасы прымання - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Экспартаванне няўдалае</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Адрас</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">непазначаны</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Дыялог сакрэтнай фразы</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Увядзіце кодавую фразу</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Новая кодавая фраза</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Паўтарыце новую кодавую фразу</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Паказаць кодавую фразу</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Зашыфраваць гаманец.</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Гэтая аперацыя патрабуе кодавую фразу, каб рзблакаваць гаманец.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Разблакаваць гаманец</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Змяніць пароль</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Пацвердзіце шыфраванне гаманца</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Увага: калі вы зашыфруеце свой гаманец і страціце парольную фразу, то &lt;b&gt;СТРАЦІЦЕ ЎСЕ СВАЕ БІТКОЙНЫ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Ці ўпэўненыя вы, што жадаеце зашыфраваць свой гаманец?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Гаманец зашыфраваны</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Гаманец будзе зашыфраваны</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">ВАЖНА: Усе папярэднія копіі гаманца варта замяніць новым зашыфраваным файлам. У мэтах бяспекі папярэднія копіі незашыфраванага файла-гаманца стануць неўжывальнымі, калі вы станеце карыстацца новым зашыфраваным гаманцом.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Шыфраванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Шыфраванне гаманца не адбылося з-за ўнутранай памылкі. Гаманец незашыфраваны.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Уведдзеныя паролі не супадаюць</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Разблакаванне гаманца няўдалае</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Уведзены пароль  для расшыфравання гаманца памылковы</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Парольная фраза гаманца паспяхова зменена.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Увага: Caps Lock уключаны!</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>unknown</source>
        <translation type="unfinished">невядома</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Колькасць</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation type="unfinished">%1 і %2</translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    </context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">Агляд</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Паказвае агульныя звесткі аб гаманцы</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">Транзакцыі</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Праглядзець гісторыю транзакцый</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">Выйсці</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Выйсці з праграмы</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">Аб Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Паказаць інфармацыю аб Qt</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Даслаць манеты на Біткойн-адрас</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Зрабіце копію гаманца ў іншае месца</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Змяніць пароль шыфравання гаманца</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">Даслаць</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">Атрымаць</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Зашыфраваць прыватныя ключы, якия належаць вашаму гаманцу</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Падпісаць паведамленне з дапамогай Біткойн-адраса каб даказаць, што яно належыць вам</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Спраўдзіць паведамленне з дапамогай Біткойн-адраса каб даказаць, што яно належыць вам</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">Ф&amp;айл</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">Наладкі</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">Дапамога</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and bitcoin: URIs)</source>
        <translation type="unfinished">Запатрабаваць плацёж (генеруецца QR-код для біткойн URI)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished">Паказаць спіс адрасоў і метак для дасылання</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Паказаць спіс адрасоў і метак для прымання</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">Опцыі каманднага радка</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 таму</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Апошні прыняты блок генераваны %1 таму.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Транзакцыи пасля гэтай не будуць бачныя.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Памылка</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Увага</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Інфармацыя</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Сінхранізавана</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Дата: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Колькасць: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Тып: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Метка: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Адрас: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Дасланыя транзакцыі</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Прынятыя транзакцыі</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Гаманец &lt;b&gt;зашыфраваны&lt;/b&gt; і зараз &lt;b&gt;разблакаваны&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Гаманец &lt;b&gt;зашыфраваны&lt;/b&gt; і зараз &lt;b&gt;заблакаваны&lt;/b&gt;</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Колькасць:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Байтаў:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Колькасць:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Камісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Пасля камісіі:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation type="unfinished">(не)выбраць ўсё</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Рэжым дрэва</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Рэжым спіса</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Колькасць</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Прыняць праз метку</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Прыняць праз адрас</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Пацверджанняў</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Пацверджана</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Капіяваць камісію</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Капіяваць з выняткам камісіі</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Капіяваць байты</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">непазначаны</translation>
    </message>
    </context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Гаманец</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Рэдагаваць Адрас</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">Метка</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">Адрас</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Новы адрас для дасылання</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Рэдагаваць адрас прымання</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Рэдагаваць адрас дасылання</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Немагчыма разблакаваць гаманец</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Генерацыя новага ключа няўдалая</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Будзе створаны новы каталог з данымі.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">імя</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation type="unfinished">Каталог ужо існуе. Дадайце %1 калі вы збіраецеся стварыць тут новы каталог.</translation>
    </message>
    </context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Опцыі каманднага радка</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Вітаем</translation>
    </message>
    <message>
        <source>Bitcoin</source>
        <translation type="unfinished">Біткойн</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Памылка</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Форма</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Уставіць адрас з буферу абмена</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Опцыі</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation type="unfinished">Гаманец</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Памылка</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Форма</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Адрас</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Тып</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">Інфармацыя</translation>
    </message>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Колькасць:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">Метка:</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Немагчыма разблакаваць гаманец</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Колькасць:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Паведамленне:</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">Капіяваць адрас</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Метка</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Паведамленне</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">непазначаны</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Даслаць Манеты</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation type="unfinished">Недастаткова сродкаў</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Колькасць:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Байтаў:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Колькасць:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Камісія:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Пасля камісіі:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Даслаць адразу некалькім атрымальнікам</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Баланс:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Пацвердзіць дасыланне</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">Капіяваць колькасць</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Капіяваць камісію</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Капіяваць з выняткам камісіі</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Капіяваць байты</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation type="unfinished">Пацвердзіць дасыланне манет</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation type="unfinished">Велічыня плацяжу мае быць больш за 0.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">непазначаны</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">Колькасць:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation type="unfinished">Заплаціць да:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">Метка:</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Уставіць адрас з буферу абмена</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Паведамленне:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Уставіць адрас з буферу абмена</translation>
    </message>
    </context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>%1/unconfirmed</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in at least one block, but less than 6 blocks.</extracomment>
        <translation type="unfinished">%1/непацверджана</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in 6 or more blocks.</extracomment>
        <translation type="unfinished">%1 пацверджанняў</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished">Статус</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">невядома</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Паведамленне</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation type="unfinished">Каментар</translation>
    </message>
    <message>
        <source>Transaction ID</source>
        <translation type="unfinished">ID</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Колькасць</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation type="unfinished">Гэтая панэль паказвае дэтальнае апісанне транзакцыі</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Тып</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Метка</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation type="unfinished">Пацверджана (%1 пацверджанняў)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation type="unfinished">Згенеравана, але не прынята</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Прынята з</translation>
    </message>
    <message>
        <source>Received from</source>
        <translation type="unfinished">Прынята ад</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Даслана да</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Здабыта</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">непазначаны</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation type="unfinished">Статус транзакцыі. Навядзіце курсар на гэтае поле, каб паказаць колькасць пацверджанняў.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation type="unfinished">Дата і час, калі транзакцыя была прынята.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation type="unfinished">Тып транзакцыі</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation type="unfinished">Колькасць аднятая ці даданая да балансу.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">Усё</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">Сёння</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Гэты тыдзень</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Гэты месяц</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Мінулы месяц</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Гэты год</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Прынята з</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Даслана да</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Здабыта</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Іншыя</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation type="unfinished">Мін. колькасць</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Пацверджана</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Дата</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Тып</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Метка</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Адрас</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Экспартаванне няўдалае</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Прамежак:</translation>
    </message>
    <message>
        <source>to</source>
        <translation type="unfinished">да</translation>
    </message>
</context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Error</source>
        <translation type="unfinished">Памылка</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Даслаць Манеты</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">Экспарт</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Экспартаваць гэтыя звесткі у файл</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Загрузка выканана</translation>
    </message>
    <message>
        <source>Error initializing block database</source>
        <translation type="unfinished">Памылка ініцыялізацыі базвы звестак блокаў</translation>
    </message>
    <message>
        <source>Error loading block database</source>
        <translation type="unfinished">Памылка загрузкі базвы звестак блокаў</translation>
    </message>
    <message>
        <source>Error opening block database</source>
        <translation type="unfinished">Памылка адчынення базы звестак блокаў</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation type="unfinished">Недастаткова сродкаў</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation type="unfinished">Памылка подпісу транзакцыі</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation type="unfinished">Гэта эксперыментальная праграма.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">Транзакцыя занадта малая</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">Транзакцыя занадта вялікая</translation>
    </message>
    </context>
</TS>